@@ -26,13 +26,13 @@
 
 #include <KConfigDialog>
 #include <KNS3/DownloadDialog>
-#include <KNS3/DownloadManager>
+#include <KNSCore/DownloadManager>
 
 ComicUpdater::ComicUpdater( QObject *parent )
   : QObject( parent ),
-    mDownloadManager( 0 ),
+    mDownloadManager(nullptr),
     mUpdateIntervall( 3 ),
-    m_updateTimer( 0 )
+    m_updateTimer(nullptr)
 {
 }
 
@@ -85,21 +85,19 @@ void ComicUpdater::checkForUpdate()
     }
 }
 
-void ComicUpdater::slotUpdatesFound( const KNS3::Entry::List &entries )
+void ComicUpdater::slotUpdatesFound(const KNSCore::EntryInternal::List& entries)
 {
     for ( int i = 0; i < entries.count(); ++i ) {
         downloadManager()->installEntry( entries[ i ] );
     }
 }
 
-KNS3::DownloadManager *ComicUpdater::downloadManager()
+KNSCore::DownloadManager *ComicUpdater::downloadManager()
 {
     if ( !mDownloadManager ) {
-        mDownloadManager = new KNS3::DownloadManager( "comic.knsrc", this );
-        connect(mDownloadManager, &KNS3::DownloadManager::searchResult, this, &ComicUpdater::slotUpdatesFound);
+        mDownloadManager = new KNSCore::DownloadManager(QStringLiteral("comic.knsrc"), this );
+        connect(mDownloadManager, &KNSCore::DownloadManager::searchResult, this, &ComicUpdater::slotUpdatesFound);
     }
 
     return mDownloadManager;
 }
-
-#include "comicupdater.moc"
