@@ -19,13 +19,13 @@
 
 #include "cachedprovider.h"
 
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTimer>
-#include <QtCore/QThreadPool>
+#include <QFile>
+#include <QFileInfo>
+#include <QTimer>
+#include <QThreadPool>
 #include <QStandardPaths>
 #include <QDir>
-#include <QtGui/QImage>
+#include <QDateTime>
 
 #include <QDebug>
 
@@ -59,7 +59,7 @@ QString CachedProvider::identifierToPath( const QString &identifier )
     const QString dataDir = QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/plasma_engine_potd/");
     QDir d;
     d.mkpath(dataDir);
-    return QString( dataDir + identifier );
+    return dataDir + identifier;
 }
 
 
@@ -98,10 +98,10 @@ bool CachedProvider::isCached( const QString &identifier, bool ignoreAge )
         return false;
     }
 
-    if (!ignoreAge && !identifier.contains( ':' ) ) {
+    if (!ignoreAge && !identifier.contains(QLatin1Char(':'))) {
         // no date in the identifier, so it's a daily; check to see ifthe modification time is today
         QFileInfo info( path );
-        if ( info.lastModified().daysTo( QDateTime::currentDateTime() ) >= 1 ) {
+        if ( info.lastModified().daysTo( QDateTime::currentDateTime() ) > 1 ) {
             return false;
         }
     }
