@@ -22,6 +22,10 @@
 #define EPODPROVIDER_H
 
 #include "potdprovider.h"
+// Qt
+#include <QImage>
+
+class KJob;
 
 /**
  * This class provides the image for EPOD 
@@ -44,7 +48,7 @@ class EpodProvider : public PotdProvider
         /**
          * Destroys the EPOD provider.
          */
-        ~EpodProvider();
+        ~EpodProvider() override;
 
         /**
          * Returns the requested image.
@@ -52,14 +56,14 @@ class EpodProvider : public PotdProvider
          * Note: This method returns only a valid image after the
          *       finished() signal has been emitted.
          */
-        QImage image() const Q_DECL_OVERRIDE;
+        QImage image() const override;
 
     private:
-      class Private;
-      Private* const d;
+        void pageRequestFinished(KJob *job);
+        void imageRequestFinished(KJob *job);
 
-      Q_PRIVATE_SLOT( d, void pageRequestFinished( KJob* ) )
-      Q_PRIVATE_SLOT( d, void imageRequestFinished( KJob* ) )
+    private:
+        QImage mImage;
 };
 
 #endif
