@@ -21,7 +21,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QGridLayout>
 
 #include <KConfigGroup>
-#include <KDebug>
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KSharedConfig>
@@ -110,6 +109,6 @@ void SpellCheckConfig::defaults()
 }
 
 K_PLUGIN_FACTORY(SpellCheckConfigFactory,
-                 registerPlugin<SpellCheckConfig>("kcm_krunner_spellcheck");)
+                 registerPlugin<SpellCheckConfig>(QStringLiteral("kcm_krunner_spellcheck"));)
 
 #include "spellcheck_config.moc"
